import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Button, Modal, notification } from 'antd'

import zhCN from '@/locales/zh-CN/model.js'
import enUS from '@/locales/en-US/model.js'
import SettingForm from './settingform'
import Api from '@/api'

class TransferWrap extends Component {
  static propTpyes = {
    MenuID: PropTypes.string
  }

  state = {
    dict: sessionStorage.getItem('lang') !== 'en-US' ? zhCN : enUS,
    visible: false,
    loading: false,
    translist: []
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState))
  }

  verifySubmit = () => {
    const { MenuID } = this.props

    this.verifyRef.handleConfirm().then(res => {
      let param = {
        func: 's_sVersionDetail_CloudAdd',
        kei_no: sessionStorage.getItem('kei_no'),
        kei_no_detail: sessionStorage.getItem('typename'),
        lang: sessionStorage.getItem('lang'),
        BID: res.VersionName,
        VType: 'mob_menu',
        TrdMenuID: MenuID
      }

      this.setState({
        loading: true
      })
      
      Api.getCloudConfig(param).then(result => {
        if (result.status) {
          notification.success({
            top: 92,
            message: '操作成功！',
            duration: 3
          })
          this.setState({
            loading: false,
            visible: false
          })
        } else {
          this.setState({
            loading: false
          })
          notification.warning({
            top: 92,
            message: result.message,
            duration: 5
          })
        }
      }, () => {
        this.setState({
          loading: false
        })
      })
    })
  }

  getTransList = () => {
    let param = {
      func: 's_get_sVersion',
      dataM: 'Y',
      PageSize: 9999,
      PageIndex: 1,
      OrderCol: 'ID desc'
    }

    this.setState({
      visible: true,
      loading: false
    })

    Api.getCloudConfig(param).then(result => {
      if (result.status) {
        this.setState({
          translist: result.data
        })
      } else {
        notification.warning({
          top: 92,
          message: result.message,
          duration: 5
        })
      }
    })
  }

  render () {
    const { visible, dict, loading, translist } = this.state

    return (
      <div className="transfer-wrap">
        <Button icon="pull-request" className="mk-border-green" onClick={this.getTransList}>传输号</Button>
        <Modal
          title="加入传输号"
          visible={visible}
          width={500}
          maskClosable={false}
          okText={dict['model.submit']}
          onOk={this.verifySubmit}
          onCancel={() => { this.setState({ visible: false }) }}
          confirmLoading={loading}
          destroyOnClose
        >
          <SettingForm
            dict={dict}
            translist={translist}
            wrappedComponentRef={(inst) => this.verifyRef = inst}
          />
        </Modal>
      </div>
    )
  }
}

export default TransferWrap